from ._nox import (  # noqa
    build_docs,
    install_and_run_pytest,
    login_testuser1,
    run_pre_commit,
    setup_test_instances_from_main_branch,
)
